You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@felix.apache.org by ri...@apache.org on 2005/08/19 21:54:41 UTC

svn commit: r233548 [6/6] - in /incubator/felix/trunk: ./ src/org/apache/felix/ src/org/apache/felix/bundlerepository/ src/org/apache/felix/bundlerepository/impl/ src/org/apache/felix/bundlerepository/impl/kxmlsax/ src/org/apache/felix/bundlerepository...

Added: incubator/felix/trunk/src/org/apache/felix/shell/impl/UninstallCommandImpl.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/apache/felix/shell/impl/UninstallCommandImpl.java?rev=233548&view=auto
==============================================================================
--- incubator/felix/trunk/src/org/apache/felix/shell/impl/UninstallCommandImpl.java (added)
+++ incubator/felix/trunk/src/org/apache/felix/shell/impl/UninstallCommandImpl.java Fri Aug 19 12:53:58 2005
@@ -0,0 +1,91 @@
+/*
+ *   Copyright 2005 The Apache Software Foundation
+ *
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ *
+ */
+package org.apache.felix.shell.impl;
+
+import java.io.PrintStream;
+import java.util.StringTokenizer;
+
+import org.apache.felix.shell.Command;
+import org.osgi.framework.*;
+
+public class UninstallCommandImpl implements Command
+{
+    private BundleContext m_context = null;
+
+    public UninstallCommandImpl(BundleContext context)
+    {
+        m_context = context;
+    }
+
+    public String getName()
+    {
+        return "uninstall";
+    }
+
+    public String getUsage()
+    {
+        return "uninstall <id> [<id> ...]";
+    }
+
+    public String getShortDescription()
+    {
+        return "uninstall bundle(s).";
+    }
+
+    public void execute(String s, PrintStream out, PrintStream err)
+    {
+        StringTokenizer st = new StringTokenizer(s, " ");
+
+        // Ignore the command name.
+        st.nextToken();
+
+        // There must be at least one bundle ID.
+        if (st.countTokens() >= 1)
+        {
+            while (st.hasMoreTokens())
+            {
+                String id = st.nextToken().trim();
+
+                try {
+                    long l = Long.parseLong(id);
+                    Bundle bundle = m_context.getBundle(l);
+                    if (bundle != null)
+                    {
+                        bundle.uninstall();
+                    }
+                    else
+                    {
+                        err.println("Bundle ID " + id + " is invalid.");
+                    }
+                } catch (NumberFormatException ex) {
+                    err.println("Unable to parse id '" + id + "'.");
+                } catch (BundleException ex) {
+                    if (ex.getNestedException() != null)
+                        err.println(ex.getNestedException().toString());
+                    else
+                        err.println(ex.toString());
+                } catch (Exception ex) {
+                    err.println(ex.toString());
+                }
+            }
+        }
+        else
+        {
+            err.println("Incorrect number of arguments");
+        }
+    }
+}
\ No newline at end of file

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/UninstallCommandImpl.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/UninstallCommandImpl.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Added: incubator/felix/trunk/src/org/apache/felix/shell/impl/UpdateCommandImpl.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/apache/felix/shell/impl/UpdateCommandImpl.java?rev=233548&view=auto
==============================================================================
--- incubator/felix/trunk/src/org/apache/felix/shell/impl/UpdateCommandImpl.java (added)
+++ incubator/felix/trunk/src/org/apache/felix/shell/impl/UpdateCommandImpl.java Fri Aug 19 12:53:58 2005
@@ -0,0 +1,178 @@
+/*
+ *   Copyright 2005 The Apache Software Foundation
+ *
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ *
+ */
+package org.apache.felix.shell.impl;
+
+import java.io.*;
+import java.net.MalformedURLException;
+import java.net.URL;
+import java.util.StringTokenizer;
+
+import org.apache.felix.shell.CdCommand;
+import org.apache.felix.shell.Command;
+import org.osgi.framework.*;
+
+public class UpdateCommandImpl implements Command
+{
+    private BundleContext m_context = null;
+
+    public UpdateCommandImpl(BundleContext context)
+    {
+        m_context = context;
+    }
+
+    public String getName()
+    {
+        return "update";
+    }
+
+    public String getUsage()
+    {
+        return "update <id> [<URL>]";
+    }
+
+    public String getShortDescription()
+    {
+        return "update bundle.";
+    }
+
+    public void execute(String s, PrintStream out, PrintStream err)
+    {
+        StringTokenizer st = new StringTokenizer(s, " ");
+
+        // Ignore the command name.
+        st.nextToken();
+
+        // There should be at least a bundle ID, but there may
+        // also be a URL.
+        if ((st.countTokens() == 1) || (st.countTokens() == 2))
+        {
+            String id = st.nextToken().trim();
+            String location = st.countTokens() == 0 ? null : st.nextToken().trim();
+
+            if (location != null)
+            {
+                location = absoluteLocation(location);
+
+                if (location == null)
+                {
+                    err.println("Malformed location: " + location);
+                }
+            }
+
+            try
+            {
+                // Get the bundle id.
+                long l = Long.parseLong(id);
+
+                // Get the bundle.
+                Bundle bundle = m_context.getBundle(l);
+                if (bundle != null)
+                {
+                    // Create input stream from location if present
+                    // and use it to update, otherwise just update.
+                    if (location != null)
+                    {
+                        InputStream is = new URL(location).openStream();
+                        bundle.update(is);
+                    }
+                    else
+                    {
+                        bundle.update();
+                    }
+                }
+                else
+                {
+                    err.println("Bundle ID " + id + " is invalid.");
+                }
+            }
+            catch (NumberFormatException ex)
+            {
+                err.println("Unable to parse id '" + id + "'.");
+            }
+            catch (MalformedURLException ex)
+            {
+                err.println("Unable to parse URL.");
+            }
+            catch (IOException ex)
+            {
+                err.println("Unable to open input stream: " + ex);
+            }
+            catch (BundleException ex)
+            {
+                if (ex.getNestedException() != null)
+                {
+                    err.println(ex.getNestedException().toString());
+                }
+                else
+                {
+                    err.println(ex.toString());
+                }
+            }
+            catch (Exception ex)
+            {
+                err.println(ex.toString());
+            }
+        }
+        else
+        {
+            err.println("Incorrect number of arguments");
+        }
+    }
+
+    private String absoluteLocation(String location)
+    {
+        if (!location.endsWith(".jar"))
+        {
+            location = location + ".jar";
+        }
+        try
+        {
+            new URL(location);
+        }
+        catch (MalformedURLException ex)
+        {
+            // Try to create a valid URL using the base URL
+            // contained in the "cd" command service.
+            String baseURL = "";
+
+            try
+            {
+                // Get a reference to the "cd" command service.
+                ServiceReference ref = m_context.getServiceReference(
+                    org.apache.felix.shell.CdCommand.class.getName());
+
+                if (ref != null)
+                {
+                    CdCommand cd = (CdCommand) m_context.getService(ref);
+                    baseURL = cd.getBaseURL();
+                    baseURL = (baseURL == null) ? "" : baseURL;
+                    m_context.ungetService(ref);
+                }
+
+                String theURL = baseURL + location;
+                new URL(theURL);
+
+            }
+            catch (Exception ex2)
+            {
+                return null;
+            }
+            location = baseURL + location;
+        }
+        return location;
+    }
+}
\ No newline at end of file

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/UpdateCommandImpl.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/UpdateCommandImpl.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Added: incubator/felix/trunk/src/org/apache/felix/shell/impl/Util.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/apache/felix/shell/impl/Util.java?rev=233548&view=auto
==============================================================================
--- incubator/felix/trunk/src/org/apache/felix/shell/impl/Util.java (added)
+++ incubator/felix/trunk/src/org/apache/felix/shell/impl/Util.java Fri Aug 19 12:53:58 2005
@@ -0,0 +1,101 @@
+/*
+ *   Copyright 2005 The Apache Software Foundation
+ *
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ *
+ */
+package org.apache.felix.shell.impl;
+
+import org.osgi.framework.Bundle;
+import org.osgi.framework.Constants;
+
+public class Util
+{
+    public static String getBundleName(Bundle bundle)
+    {
+        if (bundle != null)
+        {
+            String name = (String) bundle.getHeaders().get(Constants.BUNDLE_NAME);
+            return (name == null)
+                ? "Bundle " + Long.toString(bundle.getBundleId())
+                : name + " (" + Long.toString(bundle.getBundleId()) + ")";
+        }
+        return "[STALE BUNDLE]";
+    }
+
+    private static StringBuffer m_sb = new StringBuffer();
+
+    public static String getUnderlineString(String s)
+    {
+        synchronized (m_sb)
+        {
+            m_sb.delete(0, m_sb.length());
+            for (int i = 0; i < s.length(); i++)
+            {
+                m_sb.append('-');
+            }
+            return m_sb.toString();
+        }
+    }
+
+    public static String getValueString(Object obj)
+    {
+        synchronized (m_sb)
+        {
+            if (obj instanceof String)
+            {
+                return (String) obj;
+            }
+            else if (obj instanceof String[])
+            {
+                String[] array = (String[]) obj;
+                m_sb.delete(0, m_sb.length());
+                for (int i = 0; i < array.length; i++)
+                {
+                    if (i != 0)
+                    {
+                        m_sb.append(", ");
+                    }
+                    m_sb.append(array[i].toString());
+                }
+                return m_sb.toString();
+            }
+            else if (obj instanceof Boolean)
+            {
+                return ((Boolean) obj).toString();
+            }
+            else if (obj instanceof Long)
+            {
+                return ((Long) obj).toString();
+            }
+            else if (obj instanceof Integer)
+            {
+                return ((Integer) obj).toString();
+            }
+            else if (obj instanceof Short)
+            {
+                return ((Short) obj).toString();
+            }
+            else if (obj instanceof Double)
+            {
+                return ((Double) obj).toString();
+            }
+            else if (obj instanceof Float)
+            {
+                return ((Float) obj).toString();
+            }
+
+            return "<unknown value type>";
+        }
+    }
+}
\ No newline at end of file

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/Util.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/Util.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Added: incubator/felix/trunk/src/org/apache/felix/shell/impl/VersionCommandImpl.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/apache/felix/shell/impl/VersionCommandImpl.java?rev=233548&view=auto
==============================================================================
--- incubator/felix/trunk/src/org/apache/felix/shell/impl/VersionCommandImpl.java (added)
+++ incubator/felix/trunk/src/org/apache/felix/shell/impl/VersionCommandImpl.java Fri Aug 19 12:53:58 2005
@@ -0,0 +1,52 @@
+/*
+ *   Copyright 2005 The Apache Software Foundation
+ *
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ *
+ */
+package org.apache.felix.shell.impl;
+
+import java.io.PrintStream;
+
+import org.apache.felix.shell.Command;
+import org.osgi.framework.BundleContext;
+
+public class VersionCommandImpl implements Command
+{
+    private BundleContext m_context = null;
+
+    public VersionCommandImpl(BundleContext context)
+    {
+        m_context = context;
+    }
+
+    public String getName()
+    {
+        return "version";
+    }
+
+    public String getUsage()
+    {
+        return "version";
+    }
+
+    public String getShortDescription()
+    {
+        return "display version of framework.";
+    }
+
+    public void execute(String s, PrintStream out, PrintStream err)
+    {
+        out.println(m_context.getProperty("felix.version"));
+    }
+}

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/VersionCommandImpl.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/felix/trunk/src/org/apache/felix/shell/impl/VersionCommandImpl.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Added: incubator/felix/trunk/src/org/apache/felix/shell/impl/manifest.mf
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/apache/felix/shell/impl/manifest.mf?rev=233548&view=auto
==============================================================================
--- incubator/felix/trunk/src/org/apache/felix/shell/impl/manifest.mf (added)
+++ incubator/felix/trunk/src/org/apache/felix/shell/impl/manifest.mf Fri Aug 19 12:53:58 2005
@@ -0,0 +1,13 @@
+Bundle-Name: Shell Service
+Bundle-SymbolicName: org.apache.felix.shell.impl
+Bundle-Description: A simple command shell service for Felix.
+Bundle-Version: 1.0.2
+Bundle-Activator: org.apache.felix.shell.impl.Activator
+Bundle-ClassPath: .
+Import-Package: 
+ org.osgi.framework,
+ org.osgi.service.startlevel,
+ org.osgi.service.packageadmin
+Export-Package: 
+ org.apache.felix.shell; specification-version="1.0.0",
+ org.ungoverned.osgi.service.shell; specification-version="1.0.0"

Added: incubator/felix/trunk/src/org/apache/felix/shelltui/Activator.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/apache/felix/shelltui/Activator.java?rev=233548&view=auto
==============================================================================
--- incubator/felix/trunk/src/org/apache/felix/shelltui/Activator.java (added)
+++ incubator/felix/trunk/src/org/apache/felix/shelltui/Activator.java Fri Aug 19 12:53:58 2005
@@ -0,0 +1,160 @@
+/*
+ *   Copyright 2005 The Apache Software Foundation
+ *
+ *   Licensed under the Apache License, Version 2.0 (the "License");
+ *   you may not use this file except in compliance with the License.
+ *   You may obtain a copy of the License at
+ *
+ *       http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *   Unless required by applicable law or agreed to in writing, software
+ *   distributed under the License is distributed on an "AS IS" BASIS,
+ *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *   See the License for the specific language governing permissions and
+ *   limitations under the License.
+ *
+ */
+package org.apache.felix.shelltui;
+
+import java.io.*;
+
+import org.apache.felix.shell.ShellService;
+import org.osgi.framework.*;
+
+public class Activator implements BundleActivator
+{
+    private transient BundleContext m_context = null;
+    private transient ShellTuiRunnable m_runnable = null;
+    private transient ServiceReference m_shellRef = null;
+    private transient ShellService m_shell = null;
+
+    public void start(BundleContext context)
+    {
+        m_context = context;
+
+        // Listen for registering/unregistering impl service.
+        ServiceListener sl = new ServiceListener() {
+            public void serviceChanged(ServiceEvent event)
+            {
+                synchronized (Activator.this)
+                {
+                    // Ignore additional services if we already have one.
+                    if ((event.getType() == ServiceEvent.REGISTERED)
+                        && (m_shellRef != null))
+                    {
+                        return;
+                    }
+                    // Initialize the service if we don't have one.
+                    else if ((event.getType() == ServiceEvent.REGISTERED)
+                        && (m_shellRef == null))
+                    {
+                        initializeService();
+                    }
+                    // Unget the service if it is unregistering.
+                    else if ((event.getType() == ServiceEvent.UNREGISTERING)
+                        && event.getServiceReference().equals(m_shellRef))
+                    {
+                        m_context.ungetService(m_shellRef);
+                        m_shellRef = null;
+                        m_shell = null;
+                        // Try to get another service.
+                        initializeService();
+                    }
+                }
+            }
+        };
+        try {
+            m_context.addServiceListener(sl,
+                "(objectClass="
+                + org.apache.felix.shell.ShellService.class.getName()
+                + ")");
+        } catch (InvalidSyntaxException ex) {
+            System.err.println("ShellTuiActivator: Cannot add service listener.");
+            System.err.println("ShellTuiActivator: " + ex);
+        }
+
+        // Now try to manually initialize the impl service
+        // since one might already be available.
+        initializeService();
+
+        // Start impl thread.
+        new Thread(
+            m_runnable = new ShellTuiRunnable(),
+            "Felix Shell TUI").start();
+    }
+
+    private synchronized void initializeService()
+    {
+        if (m_shell != null)
+            return;
+        m_shellRef = m_context.getServiceReference(
+            org.apache.felix.shell.ShellService.class.getName());
+        if (m_shellRef == null)
+            return;
+        m_shell = (ShellService) m_context.getService(m_shellRef);
+    }
+
+    public void stop(BundleContext context)
+    {
+        if (m_runnable != null)
+        {
+            m_runnable.stop();
+        }
+    }
+
+    private class ShellTuiRunnable implements Runnable
+    {
+        private boolean stop = false;
+
+        public void stop()
+        {
+            stop = true;
+        }
+
+        public void run()
+        {
+            String line = null;
+            BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
+
+            while (!stop)
+            {
+                System.out.print("-> ");
+
+                try {
+                    line = in.readLine();
+                } catch (IOException ex) {
+                    System.err.println("Could not read input, please try again.");
+                    continue;
+                }
+
+                synchronized (Activator.this)
+                {
+                    if (m_shell == null)
+                    {
+                        System.out.println("No impl service available.");
+                        continue;
+                    }
+
+                    if (line == null)
+                    {
+                        continue;
+                    }
+
+                    line = line.trim();
+
+                    if (line.length() == 0)
+                    {
+                        continue;
+                    }
+
+                    try {
+                        m_shell.executeCommand(line, System.out, System.err);
+                    } catch (Exception ex) {
+                        System.err.println("ShellTuiActivator: " + ex);
+                        ex.printStackTrace();
+                    }
+                }
+            }
+        }
+    }
+}

Propchange: incubator/felix/trunk/src/org/apache/felix/shelltui/Activator.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/felix/trunk/src/org/apache/felix/shelltui/Activator.java
------------------------------------------------------------------------------
    svn:keywords = "Author Date Id Revision"

Added: incubator/felix/trunk/src/org/apache/felix/shelltui/manifest.mf
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/apache/felix/shelltui/manifest.mf?rev=233548&view=auto
==============================================================================
--- incubator/felix/trunk/src/org/apache/felix/shelltui/manifest.mf (added)
+++ incubator/felix/trunk/src/org/apache/felix/shelltui/manifest.mf Fri Aug 19 12:53:58 2005
@@ -0,0 +1,7 @@
+Bundle-Name: Shell TUI
+Bundle-SymbolicName: org.apache.felix.shelltui
+Bundle-Description: A simple textual user interface for Felix's the shell service.
+Bundle-Version: 1.0.0
+Bundle-Activator: org.apache.felix.shelltui.Activator
+Bundle-ClassPath: .
+Import-Package: org.osgi.framework, org.apache.felix.shell

Modified: incubator/felix/trunk/src/org/osgi/framework/AdminPermission.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/osgi/framework/AdminPermission.java?rev=233548&r1=233547&r2=233548&view=diff
==============================================================================
--- incubator/felix/trunk/src/org/osgi/framework/AdminPermission.java (original)
+++ incubator/felix/trunk/src/org/osgi/framework/AdminPermission.java Fri Aug 19 12:53:58 2005
@@ -14,7 +14,7 @@
 import java.io.InputStream;
 import java.security.*;
 import java.util.*;
-import org.apache.osgi.framework.FilterImpl;
+import org.apache.felix.framework.FilterImpl;
 
 /**
  * Indicates the caller's authority to perform specific privileged administrative 

Modified: incubator/felix/trunk/src/org/osgi/framework/FrameworkUtil.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/osgi/framework/FrameworkUtil.java?rev=233548&r1=233547&r2=233548&view=diff
==============================================================================
--- incubator/felix/trunk/src/org/osgi/framework/FrameworkUtil.java (original)
+++ incubator/felix/trunk/src/org/osgi/framework/FrameworkUtil.java Fri Aug 19 12:53:58 2005
@@ -10,7 +10,7 @@
 
 package org.osgi.framework;
 
-import org.apache.osgi.framework.FilterImpl;
+import org.apache.felix.framework.FilterImpl;
 
 /**
  * Framework Utility class.

Modified: incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/CdCommand.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/CdCommand.java?rev=233548&r1=233547&r2=233548&view=diff
==============================================================================
--- incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/Command.java (original)
+++ incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/Command.java Fri Aug 19 12:53:58 2005
@@ -19,11 +19,11 @@
 import java.io.PrintStream;
 
 /**
- * This interface is used to define commands for the Felix shell
+ * This interface is used to define commands for the Felix impl
  * service. Any bundle wishing to create commands for the
- * shell service simply needs to create a service object that
+ * impl service simply needs to create a service object that
  * implements this interface and then register it with the OSGi
- * framework. The shell service automatically includes any
+ * framework. The impl service automatically includes any
  * registered command services in its list of available commands.
 **/
 public interface Command

Modified: incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/ShellService.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/ShellService.java?rev=233548&r1=233547&r2=233548&view=diff
==============================================================================
--- incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/ShellService.java (original)
+++ incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/ShellService.java Fri Aug 19 12:53:58 2005
@@ -21,14 +21,14 @@
 import org.osgi.framework.ServiceReference;
 
 /**
- * This interface defines the Felix shell service. The shell service
- * is an extensible, user interface neutral shell for controlling and
- * interacting with the framework. In general, the shell service assumes that
+ * This interface defines the Felix impl service. The impl service
+ * is an extensible, user interface neutral impl for controlling and
+ * interacting with the framework. In general, the impl service assumes that
  * it is operating in a command line fashion, i.e., it receives a
  * complete command line, parses it, and executes the corresponding
  * command, but graphical interfaces are also possible.
  * <p>
- * All commands in the shell service are actually implemented as OSGi
+ * All commands in the impl service are actually implemented as OSGi
  * services; these services implement the <tt>Command</tt> service
  * interface. Any bundle can implement custom commands by creating
  * command services and registering them with the OSGi framework.
@@ -36,7 +36,7 @@
 public interface ShellService
 {
     /**
-     * Returns an array of command names available in the shell service.
+     * Returns an array of command names available in the impl service.
      * @return an array of available command names or an empty array.
     **/
     public String[] getCommands();
--- incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/CdCommand.java (original)
+++ incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/CdCommand.java Fri Aug 19 12:53:58 2005
@@ -18,14 +18,14 @@
 
 /**
  * This interface defines the <tt>cd</tt> command service interface for the
  * Felix shell service. The <tt>cd</tt> command does not really change the
  * directory of the shell, rather it maintains a base URL for
  * simplifying URL entry.
  * <p>
  * For example, if the base URL is <tt>http://www.foo.com/<tt> and you
  * try to install a bundle <tt>foo.jar</tt>, the actual URL will be
  * expanded to <tt>http://www.foo.com/foo.jar</tt>. Any bundles wishing
  * to retrieve or set the current directory of the shell can use this
  * service interface.
 **/
 public interface CdCommand extends Command
@@ -33,16 +33,16 @@
     /**
      * Property used to configure the base URL.
     **/
-    public static final String BASE_URL_PROPERTY = "felix.shell.baseurl";
+    public static final String BASE_URL_PROPERTY = "felix.impl.baseurl";
 
     /**
      * Returns the current <i>directory</i> of the shell service.
      * @return the current shell directory.
     **/
     public String getBaseURL();
 
     /**
      * Sets the current <i>directory</i> of the shell service.
      * @param s the new value for the base URL.
     **/
     public void setBaseURL(String s);
@@ -18,14 +18,14 @@
 /**
  * This interface defines the <tt>cd</tt> command service interface for the
- * Felix shell service. The <tt>cd</tt> command does not really change the
- * directory of the shell, rather it maintains a base URL for
+ * Felix impl service. The <tt>cd</tt> command does not really change the
+ * directory of the impl, rather it maintains a base URL for
  * simplifying URL entry.
  * <p>
@@ -18,14 +18,14 @@
  * try to install a bundle <tt>foo.jar</tt>, the actual URL will be
  * expanded to <tt>http://www.foo.com/foo.jar</tt>. Any bundles wishing
- * to retrieve or set the current directory of the shell can use this
+ * to retrieve or set the current directory of the impl can use this
  * service interface.
 **/
@@ -33,16 +33,16 @@
 
     /**
-     * Returns the current <i>directory</i> of the shell service.
-     * @return the current shell directory.
+     * Returns the current <i>directory</i> of the impl service.
+     * @return the current impl directory.
     **/
     public String getBaseURL();
@@ -33,16 +33,16 @@
 
     /**
-     * Sets the current <i>directory</i> of the shell service.
+     * Sets the current <i>directory</i> of the impl service.
      * @param s the new value for the base URL.
     **/

Modified: incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/Command.java
URL: http://svn.apache.org/viewcvs/incubator/felix/trunk/src/org/ungoverned/osgi/service/shell/Command.java?rev=233548&r1=233547&r2=233548&view=diff
==============================================================================